{% extends 'base.html' %} {% load custom_tags_and_filters %} {% block title %}History for {{ name }}{% endblock %} {% block content %} {% if action_list %}

# History for {{ name }}

# {% button type="export" value="Export" url=request.path|concat:"?csv=true" target="_blank" %}

Date & time | User | Action {% if has_details %} | Details{% endif %}
--- | --- | --- | ---
{% for row in action_list.rows %}
{{ row.date }} | {{ row.authorizer }} | {{ row.message|linebreaksbr }} {% if has_details %} | {{ row.details|default_if_none:"" }}{% endif %}
{% endfor %}

{% else %}

{{ name }} doesn't have a change history.

{% endif %} {% endblock %}